##  Configuration
This section details how to set up microservice discovery in the CI/CD pipeline for specific Git providers.
The pipeline in this guide includes the following steps:
  1. Checking out your code.
  2. Setting up Python.
  3. Installing the necessary Python dependencies.
  4. Invoking the SAP LeanIX service discovery Python helper.
